==> members-facade-2.0.0-20190925.070937-26-sources.jar: com/bizvane/members/facade/models/po/MbrElectCardMembersPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrElectCardMembersPO implements Serializable {

	/**
	 * 只读. . mbr_member_elect_card_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "mbrMemberElectCardId", required = false, example = "")
	private Long mbrMemberElectCardId;
	/**
	 * 只读. . sys_company_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. . member_code
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 姓名. elect_card_name
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "姓名", name = "electCardName", required = false, example = "")
	private String electCardName;
	/**
	 * 只读. 手机. elect_card_mobile
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "手机", name = "electCardMobile", required = false, example = "")
	private String electCardMobile;
	/**
	 * 只读. 生日. elect_card_birthday
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "生日", name = "electCardBirthday", required = false, example = "")
	private Date electCardBirthday;
	/**
	 * 只读. 邮箱. elect_card_email
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "邮箱", name = "electCardEmail", required = false, example = "")
	private String electCardEmail;
	/**
	 * 只读. 性别. elect_card_sex
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "性别", name = "electCardSex", required = false, example = "")
	private Integer electCardSex;
	/**
	 * 只读. 开卡时间. elect_card_open_card_time
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "开卡时间", name = "electCardOpenCardTime", required = false, example = "")
	private Date electCardOpenCardTime;
	/**
	 * 只读. 绑卡时间. elect_card_bind_card_time
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "绑卡时间", name = "electCardBindCardTime", required = false, example = "")
	private Date electCardBindCardTime;
	/**
	 * 只读. 绑定状态(待定). elect_card_bind_status
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "绑定状态(待定)", name = "electCardBindStatus", required = false, example = "")
	private Integer electCardBindStatus;
	/**
	 * 只读. 1 开卡 2绑卡. elect_card_type
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "1 开卡 2绑卡", name = "electCardType", required = false, example = "")
	private Integer electCardType;
	/**
	 * 只读. 扩展字段. elect_card_extend
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "扩展字段", name = "electCardExtend", required = false, example = "")
	private String electCardExtend;
	/**
	 * 只读. 推广渠道(待定). elect_card_generalize_channel
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "推广渠道(待定)", name = "electCardGeneralizeChannel", required = false, example = "")
	private String electCardGeneralizeChannel;
	/**
	 * 只读. 微信电子会员卡code. wechat_electronic_card_code
	 */
	@io.swagger.annotations.ApiModelProperty(value = "微信电子会员卡code", name = "wechatElectronicCardCode", required = false, example = "")
	private String wechatElectronicCardCode;
	/**
	 * 只读. . valid
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modify_user_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserId", required = false, example = "")
	private Long modifyUserId;
	/**
	 * 只读. . modify_user_name
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserName", required = false, example = "")
	private String modifyUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getMbrMemberElectCardId() {
		return mbrMemberElectCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setMbrMemberElectCardId(Long mbrMemberElectCardId) {
		this.mbrMemberElectCardId = mbrMemberElectCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardName() {
		return electCardName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardName(String electCardName) {
		this.electCardName = electCardName == null ? null : electCardName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardMobile() {
		return electCardMobile;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardMobile(String electCardMobile) {
		this.electCardMobile = electCardMobile == null ? null : electCardMobile.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getElectCardBirthday() {
		return electCardBirthday;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardBirthday(Date electCardBirthday) {
		this.electCardBirthday = electCardBirthday;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardEmail() {
		return electCardEmail;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardEmail(String electCardEmail) {
		this.electCardEmail = electCardEmail == null ? null : electCardEmail.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Integer getElectCardSex() {
		return electCardSex;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardSex(Integer electCardSex) {
		this.electCardSex = electCardSex;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getElectCardOpenCardTime() {
		return electCardOpenCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardOpenCardTime(Date electCardOpenCardTime) {
		this.electCardOpenCardTime = electCardOpenCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getElectCardBindCardTime() {
		return electCardBindCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardBindCardTime(Date electCardBindCardTime) {
		this.electCardBindCardTime = electCardBindCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Integer getElectCardBindStatus() {
		return electCardBindStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardBindStatus(Integer electCardBindStatus) {
		this.electCardBindStatus = electCardBindStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Integer getElectCardType() {
		return electCardType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardType(Integer electCardType) {
		this.electCardType = electCardType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardExtend() {
		return electCardExtend;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardExtend(String electCardExtend) {
		this.electCardExtend = electCardExtend == null ? null : electCardExtend.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardGeneralizeChannel() {
		return electCardGeneralizeChannel;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardGeneralizeChannel(String electCardGeneralizeChannel) {
		this.electCardGeneralizeChannel = electCardGeneralizeChannel == null ? null : electCardGeneralizeChannel.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getModifyUserId() {
		return modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setModifyUserId(Long modifyUserId) {
		this.modifyUserId = modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getModifyUserName() {
		return modifyUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setModifyUserName(String modifyUserName) {
		this.modifyUserName = modifyUserName == null ? null : modifyUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	public String getWechatElectronicCardCode() {
		return wechatElectronicCardCode;
	}

	public void setWechatElectronicCardCode(String wechatElectronicCardCode) {
		this.wechatElectronicCardCode = wechatElectronicCardCode;
	}
}

==> members-facade-20250623-20250709.064027-2-sources.jar: com/bizvane/members/facade/models/po/MbrElectCardMembersPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrElectCardMembersPO implements Serializable {

	/**
	 * 只读. . mbr_member_elect_card_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "mbrMemberElectCardId", required = false, example = "")
	private Long mbrMemberElectCardId;
	/**
	 * 只读. . sys_company_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. . member_code
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "memberCode", required = false, example = "")
	private String memberCode;

	@io.swagger.annotations.ApiModelProperty(value = "", name = "openId", required = false, example = "")
	private String openId;

	@io.swagger.annotations.ApiModelProperty(value = "", name = "unionId", required = false, example = "")
	private String unionId;

	/**
	 * 只读. 姓名. elect_card_name
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "姓名", name = "electCardName", required = false, example = "")
	private String electCardName;
	/**
	 * 只读. 手机. elect_card_mobile
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "手机", name = "electCardMobile", required = false, example = "")
	private String electCardMobile;
	/**
	 * 只读. 生日. elect_card_birthday
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "生日", name = "electCardBirthday", required = false, example = "")
	private Date electCardBirthday;
	/**
	 * 只读. 邮箱. elect_card_email
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "邮箱", name = "electCardEmail", required = false, example = "")
	private String electCardEmail;
	/**
	 * 只读. 性别. elect_card_sex
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "性别", name = "electCardSex", required = false, example = "")
	private Integer electCardSex;
	/**
	 * 只读. 开卡时间. elect_card_open_card_time
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "开卡时间", name = "electCardOpenCardTime", required = false, example = "")
	private Date electCardOpenCardTime;
	/**
	 * 只读. 绑卡时间. elect_card_bind_card_time
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "绑卡时间", name = "electCardBindCardTime", required = false, example = "")
	private Date electCardBindCardTime;
	/**
	 * 只读. 绑定状态(待定). elect_card_bind_status
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "绑定状态(待定)", name = "electCardBindStatus", required = false, example = "")
	private Integer electCardBindStatus;
	/**
	 * 只读. 1 开卡 2绑卡. elect_card_type
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "1 开卡 2绑卡", name = "electCardType", required = false, example = "")
	private Integer electCardType;
	/**
	 * 只读. 扩展字段. elect_card_extend
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "扩展字段", name = "electCardExtend", required = false, example = "")
	private String electCardExtend;
	/**
	 * 只读. 推广渠道(待定). elect_card_generalize_channel
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "推广渠道(待定)", name = "electCardGeneralizeChannel", required = false, example = "")
	private String electCardGeneralizeChannel;
	/**
	 * 只读. 微信电子会员卡code. wechat_electronic_card_code
	 */
	@io.swagger.annotations.ApiModelProperty(value = "微信电子会员卡code", name = "wechatElectronicCardCode", required = false, example = "")
	private String wechatElectronicCardCode;
	/**
	 * 只读. . valid
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modify_user_id
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserId", required = false, example = "")
	private Long modifyUserId;
	/**
	 * 只读. . modify_user_name
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifyUserName", required = false, example = "")
	private String modifyUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getMbrMemberElectCardId() {
		return mbrMemberElectCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setMbrMemberElectCardId(Long mbrMemberElectCardId) {
		this.mbrMemberElectCardId = mbrMemberElectCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	public String getOpenId() {
		return openId;
	}

	public void setOpenId(String openId) {
		this.openId = openId;
	}

	public String getUnionId() {
		return unionId;
	}

	public void setUnionId(String unionId) {
		this.unionId = unionId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardName() {
		return electCardName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardName(String electCardName) {
		this.electCardName = electCardName == null ? null : electCardName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardMobile() {
		return electCardMobile;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardMobile(String electCardMobile) {
		this.electCardMobile = electCardMobile == null ? null : electCardMobile.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getElectCardBirthday() {
		return electCardBirthday;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardBirthday(Date electCardBirthday) {
		this.electCardBirthday = electCardBirthday;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardEmail() {
		return electCardEmail;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardEmail(String electCardEmail) {
		this.electCardEmail = electCardEmail == null ? null : electCardEmail.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Integer getElectCardSex() {
		return electCardSex;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardSex(Integer electCardSex) {
		this.electCardSex = electCardSex;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getElectCardOpenCardTime() {
		return electCardOpenCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardOpenCardTime(Date electCardOpenCardTime) {
		this.electCardOpenCardTime = electCardOpenCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getElectCardBindCardTime() {
		return electCardBindCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardBindCardTime(Date electCardBindCardTime) {
		this.electCardBindCardTime = electCardBindCardTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Integer getElectCardBindStatus() {
		return electCardBindStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardBindStatus(Integer electCardBindStatus) {
		this.electCardBindStatus = electCardBindStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Integer getElectCardType() {
		return electCardType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardType(Integer electCardType) {
		this.electCardType = electCardType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardExtend() {
		return electCardExtend;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardExtend(String electCardExtend) {
		this.electCardExtend = electCardExtend == null ? null : electCardExtend.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getElectCardGeneralizeChannel() {
		return electCardGeneralizeChannel;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setElectCardGeneralizeChannel(String electCardGeneralizeChannel) {
		this.electCardGeneralizeChannel = electCardGeneralizeChannel == null ? null : electCardGeneralizeChannel.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Long getModifyUserId() {
		return modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setModifyUserId(Long modifyUserId) {
		this.modifyUserId = modifyUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public String getModifyUserName() {
		return modifyUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setModifyUserName(String modifyUserName) {
		this.modifyUserName = modifyUserName == null ? null : modifyUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-11 10:58:35
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	public String getWechatElectronicCardCode() {
		return wechatElectronicCardCode;
	}

	public void setWechatElectronicCardCode(String wechatElectronicCardCode) {
		this.wechatElectronicCardCode = wechatElectronicCardCode;
	}
}
